from typing import Optional
from pydantic import Field

from orchestrator.domain.base import ProductBlockModel
from orchestrator.types import SubscriptionLifecycle, strEnum

import ipaddress

class SiteTier(strEnum):
    tier1 = 1
    tier2 = 2
    tier3 = 3
    tier4 = 4


class SiteBlockInactive(ProductBlockModel,
                          lifecycle=[SubscriptionLifecycle.INITIAL],
                          product_block_name="SiteBlock"):
    site_name: Optional[str] = None
    site_city: Optional[str] = None
    site_country: Optional[str] = None
    site_country_code: Optional[str] = None
    site_latitude: Optional[float] = None
    site_longitude: Optional[float] = None
    site_internal_id: Optional[int] = None
    site_bgp_community_id: Optional[int] = None
    site_tier: Optional[SiteTier] = None

class SiteBlockProvisioning(SiteBlockInactive,
                            lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    site_name: Optional[str] = None
    site_city: Optional[str] = None
    site_country: Optional[str] = None
    site_country_code: Optional[str] = None
    site_latitude: Optional[float] = None
    site_longitude: Optional[float] = None
    site_internal_id: Optional[int] = None
    site_bgp_community_id: Optional[int] = None
    site_tier: Optional[SiteTier] = None

class SiteBlock(SiteBlockProvisioning,
                  lifecycle=[SubscriptionLifecycle.ACTIVE]):
    site_name: str
    site_city: str
    site_country: str
    site_country_code: str
    site_latitude: float
    site_longitude: float
    site_internal_id: int
    site_bgp_community_id: int
    site_tier: SiteTier
